@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,15 +9,18 @@
 
 #include <QWidget>
 
-namespace Ui {
+namespace Ui
+{
 class ImportMailPage;
 }
 
-namespace Akonadi {
+namespace Akonadi
+{
 class Collection;
 }
 
-namespace MailImporter {
+namespace MailImporter
+{
 class ImportMailsWidget;
 }
 
