@@ -1,16 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef IMPORTMAILPLUGINMANAGER_H
 #define IMPORTMAILPLUGINMANAGER_H
 
+#include <KPluginMetaData>
 #include <QObject>
 #include <QVector>
-#include <KPluginMetaData>
 
-namespace LibImportWizard {
+namespace LibImportWizard
+{
 class AbstractImporter;
 }
 
