@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "importwizardutil.h"
-#include <KSharedConfig>
-#include <KConfigGroup>
+#include "importwizardsavepasswordjob.h"
 #include "libimportwizard_debug.h"
-#include <KWallet>
 #include <AkonadiCore/Tag>
 #include <AkonadiCore/TagAttribute>
 #include <AkonadiCore/TagCreateJob>
+#include <KConfigGroup>
+#include <KSharedConfig>
 
 void ImportWizardUtil::mergeLdap(const ldapStruct &ldap)
 {
@@ -53,7 +53,7 @@ void ImportWizardUtil::mergeLdap(const ldapStruct &ldap)
     }
     grp.writeEntry(QStringLiteral("SelectedVersion%1").arg(numberOfLdapSelected), QString::number(3));
     grp.writeEntry(QStringLiteral("SelectedBind%1").arg(numberOfLdapSelected), ldap.dn);
-    //TODO: Verify selectedbase
+    // TODO: Verify selectedbase
     grp.writeEntry(QStringLiteral("SelectedBase%1").arg(numberOfLdapSelected), ldap.ldapUrl.path());
     if (ldap.timeout != -1) {
         grp.writeEntry(QStringLiteral("SelectedTimeLimit%1").arg(numberOfLdapSelected), ldap.timeout);
@@ -62,7 +62,7 @@ void ImportWizardUtil::mergeLdap(const ldapStruct &ldap)
         grp.writeEntry(QStringLiteral("SelectedSizeLimit%1").arg(numberOfLdapSelected), ldap.limit);
     }
     if (!ldap.password.isEmpty()) {
-        storeInKWallet(QStringLiteral("SelectedPwdBind%1").arg(numberOfLdapSelected), ImportWizardUtil::Ldap, ldap.password);
+        storePassword(QStringLiteral("SelectedPwdBind%1").arg(numberOfLdapSelected), ImportWizardUtil::Ldap, ldap.password);
     }
     grp.sync();
 }
@@ -78,39 +78,24 @@ void ImportWizardUtil::addAkonadiTag(const QVector<tagStruct> &tagList)
     }
 }
 
-void ImportWizardUtil::storeInKWallet(const QString &name, ImportWizardUtil::ResourceType type, const QString &password)
+void ImportWizardUtil::storePassword(const QString &name, ImportWizardUtil::ResourceType type, const QString &password)
 {
-    KWallet::Wallet *wallet = nullptr;
+    auto *job = new ImportWizardSavePasswordJob;
     switch (type) {
     case Imap:
-        wallet = KWallet::Wallet::openWallet(KWallet::Wallet::NetworkWallet(), 0);
-        if (wallet && wallet->isOpen()) {
-            if (!wallet->hasFolder(QStringLiteral("imap"))) {
-                wallet->createFolder(QStringLiteral("imap"));
-            }
-            wallet->setFolder(QStringLiteral("imap"));
-            wallet->writePassword(name + QLatin1String("rc"), password);
-        }
+        job->setName(QStringLiteral("imap"));
+        job->setPassword(password);
+        job->setKey(name + QLatin1String("rc"));
         break;
     case Pop3:
-        wallet = KWallet::Wallet::openWallet(KWallet::Wallet::NetworkWallet(), 0);
-        if (wallet && wallet->isOpen()) {
-            if (!wallet->hasFolder(QStringLiteral("pop3"))) {
-                wallet->createFolder(QStringLiteral("pop3"));
-            }
-            wallet->setFolder(QStringLiteral("pop3"));
-            wallet->writePassword(name, password);
-        }
+        job->setName(QStringLiteral("pop3"));
+        job->setPassword(password);
+        job->setKey(name);
         break;
     case Ldap:
-        wallet = KWallet::Wallet::openWallet(KWallet::Wallet::LocalWallet(), 0);
-        if (wallet && wallet->isOpen()) {
-            if (!wallet->hasFolder(QStringLiteral("ldapclient"))) {
-                wallet->createFolder(QStringLiteral("ldapclient"));
-            }
-            wallet->setFolder(QStringLiteral("ldapclient"));
-            wallet->writePassword(name, password);
-        }
+        job->setName(QStringLiteral("ldapclient"));
+        job->setPassword(password);
+        job->setKey(name);
     }
-    delete wallet;
+    job->start();
 }
